py-romanify
===========

Convertor of roman/arabic numerals 

Alpha version
- missing tests and other stuff

Installation
------------
See `docs/installation.rst`_.

Usage
-----
See `docs/usage.rst`_.

Changelog
---------
See `docs/changelog.rst`_.

TODO
----
* unittest
* example script
* check doc (generate doc)
  
  * roman/arabic convert theory

* features

  * case insensitive roman numerals

.. _docs/installation.rst: docs/installation.rst
.. _docs/usage.rst: docs/usage.rst
.. _docs/changelog.rst: docs/changelog.rst
